const std = @import("std");

pub const kindle_target_query_glibc: std.Target.Query = .{
    .cpu_arch = .arm,
    .cpu_model = std.Target.Query.CpuModel{
        .explicit = &std.Target.arm.cpu.cortex_a8,
    },
    .abi = .gnueabihf,
    .os_tag = .linux,
    .glibc_version = std.SemanticVersion.parse("2.12.0") catch unreachable,
    .dynamic_linker = std.Target.DynamicLinker.init("/lib/ld-linux.so.3"),
};

const kindle_target_query_musl: std.Target.Query = .{
    .cpu_arch = .arm,
    .cpu_model = std.Target.Query.CpuModel{
        .explicit = &std.Target.arm.cpu.cortex_a8,
    },
    .abi = .musleabihf,
    .os_tag = .linux,
};

pub fn build(b: *std.Build) void {
    const target = b.standardTargetOptions(.{});
    const optimize = b.standardOptimizeOption(.{});

    const libkindle_sys = buildLibkindleSys(b, target, optimize);
    b.installArtifact(libkindle_sys);

    const kindle_mod = b.addModule("kindle", .{
        .root_source_file = b.path("src/root.zig"),
        .target = target,
        .optimize = optimize,
    });

    kindle_mod.addIncludePath(b.path("kindle/sysroot/usr/include"));
}

fn buildLibkindleSys(b: *std.Build, target: std.Build.ResolvedTarget, optimize: std.builtin.OptimizeMode) *std.Build.Step.Compile {
    const getauxval_backport_dep = b.dependency("getauxval_backport", .{
        .target = target,
        .optimize = optimize,
        .elf64 = false,
    });
    const libgetauxval_backport = getauxval_backport_dep.artifact("getauxval_backport");

    const libkindle_sys = @import("libs/kindle_sys.zig").create(b, target, optimize);
    libkindle_sys.linkLibrary(libgetauxval_backport);

    return libkindle_sys;
}
